@@ -7,7 +7,8 @@
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 package Nile::Handler::CGI;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
+our $AUTHORITY = 'cpan:MEWSOFT';
 
 =pod
 
@@ -38,8 +39,12 @@ sub run {
 
 	#$me->log->debug("CGI/FCGI request start");
 
+	$me->hook->on_request;
+
 	# direct CGI mode.
 	my $request = $me->new_request();
+	
+	$me->hook->off_request;
 
 	$me->response($me->object("Nile::HTTP::Response"));
 	my $response = $me->response;
@@ -49,6 +54,8 @@ sub run {
 	# dispatch the action
 	my $content = $me->dispatcher->dispatch;
 	#------------------------------------------------------
+	$me->hook->on_response;
+
 	# assume OK response if not set
 	$response->code(200) unless ($response->code);
 
@@ -94,6 +101,8 @@ sub run {
 	#my $res = $response->finalize;
 	#my $res = $response->headers_as_string;
 	
+	$me->hook->off_response;
+
 	my $res = $response->as_string;
 	
 	#print "Content-type: text/html;charset=utf-8\n\n";
